@@ -8,7 +8,7 @@ from .modules import *
 from re import fullmatch
 from http import HTTPStatus
 
-__version__ = '1.2.8.6'
+__version__ = '1.2.9.2'
 
 class PathMaker(dict):
     '''For storing and handling path mapping
@@ -56,13 +56,23 @@ class PyWebHost(socketserver.ThreadingMixIn, socketserver.TCPServer,):
             server.serve_forever()
 
         You can test by typing `http://localhost:1234` into your browser to retrive a glorious error page ((
-    '''
-    daemon_threads = True
+    '''    
     request_queue_size = 10
+    shutdown_timeout = 5
     def handle_error(self, socket_ : socket, client_address : tuple, error : Exception = ''):
         """Handle an error gracefully. """
         super().handle_error(socket_,client_address)
 
+    def shutdown(self):
+        """Stops the serve_forever loop.
+
+        Blocks until the loop has finished or timeout reached.
+        . This must be called while serve_forever() is running
+         in another thread, or it will deadlock.
+        """
+        self._BaseServer__shutdown_request = True
+        return self._BaseServer__is_shut_down.wait(timeout=self.shutdown_timeout)
+
     def handle(self, request : Request):
         '''
         Maps the request with the `PathMaker`
@@ -113,9 +123,13 @@ class PyWebHost(socketserver.ThreadingMixIn, socketserver.TCPServer,):
         '''
 
     def __init__(self, server_address : tuple):
+        self.daemon_threads = True
+        # Handlers terminates with the program
         self.paths = PathMaker()
         # A paths dictionary which has `lambda` objects as keys
         self.protocol_version = "HTTP/1.1"
         # What protocol version to use.        
-        # Error page format. %(`code`)d %(`message`)s %(`explain`)s are usable
+        # Error page format. %(`code`)d %(`message`)s %(`explain`)s are usable        
+        socketserver.TCPServer.allow_reuse_address = True
+        # Employ SO_REUSEADDR
         super().__init__(server_address, Request)
