@@ -192,7 +192,7 @@ class Request(StreamRequestHandler):
         try:
             self.headers = Headers.parse(self.rfile)
             if self.headers.get('Cookie'):
-                cookies = self.headers.get('Cookie').replace(' ','%20') # esacpe spaces : https://tools.ietf.org/html/rfc6265#section-4.1.1
+                cookies = self.headers.get('Cookie').replace('%20',' ').replace(' ','') # esacpe spaces : https://tools.ietf.org/html/rfc6265#section-4.1.1
                 self.cookies = SimpleCookie(cookies)                
         except client.LineTooLong as err:
             self.send_error(
@@ -397,7 +397,7 @@ class Request(StreamRequestHandler):
 
     def flush_headers(self):
         if not self.headers_buffer.response_line:
-            raise ResponseNotReady('No response line is present')
+            self.send_response(200)
         self.wfile.write(self.headers_buffer.encode())
         self.headers_buffer = Headers()
 
