@@ -323,10 +323,10 @@ class WebsocketSession(Session):
         self.request.log_debug('Websocket Connection closed')
         self.request.server.websockets.remove(self)
         # kicks ourself out
-        self.onClose()
+        self.onClose(None,None)
 
-    def onClose(self,request=None,content=None):        
-        pass
+    def onClose(self,request=None,content=None):   
+        if request:return     
 
     def __websocket_constructframe(self, data: WebsocketFrame) -> bytearray:
         '''
